==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/GeographicMapDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageTilesReadyEventArgsDescriptionMetadata } from "./ImageTilesReadyEventArgsDescriptionMetadata";
import { SeriesViewerDescriptionMetadata } from "./SeriesViewerDescriptionMetadata";
import { GeographicMapDescription } from "./GeographicMapDescription";
import { ImagesChangedEventArgsDescriptionMetadata } from "./ImagesChangedEventArgsDescriptionMetadata";
import { CancellingMultiScaleImageEventArgsDescriptionMetadata } from "./CancellingMultiScaleImageEventArgsDescriptionMetadata";
import { DownloadingMultiScaleImageEventArgsDescriptionMetadata } from "./DownloadingMultiScaleImageEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMapDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapDescriptionMetadata, _super);
    function GeographicMapDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMapDescriptionMetadata.b = function (a) {
        if (GeographicMapDescriptionMetadata.a == null) {
            GeographicMapDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMapDescriptionMetadata.c(GeographicMapDescriptionMetadata.a);
        }
        if (a.k(GeographicMapDescriptionMetadata.a)) {
            return;
        }
        a.ab(GeographicMapDescriptionMetadata.a);
        GeographicMapImageryDescriptionMetadata.d(a);
        ImageTilesReadyEventArgsDescriptionMetadata.d(a);
    };
    GeographicMapDescriptionMetadata.c = function (a) {
        SeriesViewerDescriptionMetadata.c(a);
        a.item("Zoomable", "Boolean");
        a.item("ResizeBehavior", "ExportedType:string:MapResizeBehavior");
        a.item("ResizeBehavior@names", "Auto;MaintainTopLeftPosition;MaintainCenterPosition");
        a.item("IsHorizontalWrappingEnabled", "Boolean");
        a.item("BackgroundTilingMode", "ExportedType:string:MapBackgroundTilingMode");
        a.item("BackgroundTilingMode@names", "Auto;NonWrapped;Wrapped");
        a.item("UseWorldRectForZoomBounds", "Boolean");
        a.item("SuppressZoomResetOnWorldRectChange", "Boolean");
        a.item("WorldRect", "Rect");
        a.item("ActualWorldRect", "Rect");
        a.item("BackgroundContent", "ExportedType:GeographicMapImagery");
        a.item("WindowScale", "Number:double");
        a.item("ActualWindowScale", "Number:double");
        a.item("ImageTilesReadyRef", "EventRef::imageTilesReady");
        GeographicMapDescriptionMetadata.e(a);
    };
    GeographicMapDescriptionMetadata.d = function (a) {
        GeographicMapDescriptionMetadata.b(a);
        a.ad("GeographicMap", function () { return new GeographicMapDescription(); });
        a.ac("GeographicMap", GeographicMapDescriptionMetadata.a);
    };
    GeographicMapDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Maps.XamGeographicMap");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    GeographicMapDescriptionMetadata.$t = markType(GeographicMapDescriptionMetadata, 'GeographicMapDescriptionMetadata');
    GeographicMapDescriptionMetadata.a = null;
    return GeographicMapDescriptionMetadata;
}(Base));
export { GeographicMapDescriptionMetadata };
/**
 * @hidden
 */
var GeographicMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapImageryDescriptionMetadata, _super);
    function GeographicMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMapImageryDescriptionMetadata.b = function (a) {
        if (GeographicMapImageryDescriptionMetadata.a == null) {
            GeographicMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMapImageryDescriptionMetadata.c(GeographicMapImageryDescriptionMetadata.a);
        }
        if (a.k(GeographicMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.ab(GeographicMapImageryDescriptionMetadata.a);
        GeographicMapDescriptionMetadata.d(a);
        ImageTilesReadyEventArgsDescriptionMetadata.d(a);
        ImagesChangedEventArgsDescriptionMetadata.d(a);
        CancellingMultiScaleImageEventArgsDescriptionMetadata.d(a);
        DownloadingMultiScaleImageEventArgsDescriptionMetadata.d(a);
    };
    GeographicMapImageryDescriptionMetadata.c = function (a) {
        a.item("WindowRect", "Rect");
        a.item("GeographicMap", "ExportedType:XamGeographicMap");
        a.item("Referer", "String");
        a.item("IsHorizontalWrappingEnabled", "Boolean");
        a.item("UserAgent", "String");
        a.item("Opacity", "Number:double");
        a.item("ImageTilesReadyRef", "EventRef::imageTilesReady");
        a.item("ImagesChangedRef", "EventRef::imagesChanged");
        a.item("CancellingImageRef", "EventRef::cancellingImage");
        a.item("DownloadingImageRef", "EventRef::downloadingImage");
    };
    GeographicMapImageryDescriptionMetadata.d = function (a) {
        GeographicMapImageryDescriptionMetadata.b(a);
        a.ac("GeographicMapImagery", GeographicMapImageryDescriptionMetadata.a);
    };
    GeographicMapImageryDescriptionMetadata.$t = markType(GeographicMapImageryDescriptionMetadata, 'GeographicMapImageryDescriptionMetadata');
    GeographicMapImageryDescriptionMetadata.a = null;
    return GeographicMapImageryDescriptionMetadata;
}(Base));
export { GeographicMapImageryDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/GeographicMapDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageTilesReadyEventArgsDescriptionMetadata } from "./ImageTilesReadyEventArgsDescriptionMetadata";
import { SeriesViewerDescriptionMetadata } from "./SeriesViewerDescriptionMetadata";
import { GeographicMapDescription } from "./GeographicMapDescription";
import { ImagesChangedEventArgsDescriptionMetadata } from "./ImagesChangedEventArgsDescriptionMetadata";
import { CancellingMultiScaleImageEventArgsDescriptionMetadata } from "./CancellingMultiScaleImageEventArgsDescriptionMetadata";
import { DownloadingMultiScaleImageEventArgsDescriptionMetadata } from "./DownloadingMultiScaleImageEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMapDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapDescriptionMetadata, _super);
    function GeographicMapDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMapDescriptionMetadata.b = function (a) {
        if (GeographicMapDescriptionMetadata.a == null) {
            GeographicMapDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMapDescriptionMetadata.c(GeographicMapDescriptionMetadata.a);
        }
        if (a.k(GeographicMapDescriptionMetadata.a)) {
            return;
        }
        a.ac(GeographicMapDescriptionMetadata.a);
        GeographicMapImageryDescriptionMetadata.d(a);
        ImageTilesReadyEventArgsDescriptionMetadata.d(a);
    };
    GeographicMapDescriptionMetadata.c = function (a) {
        SeriesViewerDescriptionMetadata.c(a);
        a.item("Zoomable", "Boolean");
        a.item("ResizeBehavior", "ExportedType:string:MapResizeBehavior");
        a.item("ResizeBehavior@names", "Auto;MaintainTopLeftPosition;MaintainCenterPosition");
        a.item("IsHorizontalWrappingEnabled", "Boolean");
        a.item("BackgroundTilingMode", "ExportedType:string:MapBackgroundTilingMode");
        a.item("BackgroundTilingMode@names", "Auto;NonWrapped;Wrapped");
        a.item("UseWorldRectForZoomBounds", "Boolean");
        a.item("SuppressZoomResetOnWorldRectChange", "Boolean");
        a.item("WorldRect", "Rect");
        a.item("ActualWorldRect", "Rect");
        a.item("BackgroundContent", "ExportedType:GeographicMapImagery");
        a.item("WindowScale", "Number:double");
        a.item("ActualWindowScale", "Number:double");
        a.item("ImageTilesReadyRef", "EventRef::imageTilesReady");
        GeographicMapDescriptionMetadata.e(a);
    };
    GeographicMapDescriptionMetadata.d = function (a) {
        GeographicMapDescriptionMetadata.b(a);
        a.ae("GeographicMap", function () { return new GeographicMapDescription(); });
        a.ad("GeographicMap", GeographicMapDescriptionMetadata.a);
    };
    GeographicMapDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Maps.XamGeographicMap");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    GeographicMapDescriptionMetadata.$t = markType(GeographicMapDescriptionMetadata, 'GeographicMapDescriptionMetadata');
    GeographicMapDescriptionMetadata.a = null;
    return GeographicMapDescriptionMetadata;
}(Base));
export { GeographicMapDescriptionMetadata };
/**
 * @hidden
 */
var GeographicMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMapImageryDescriptionMetadata, _super);
    function GeographicMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMapImageryDescriptionMetadata.b = function (a) {
        if (GeographicMapImageryDescriptionMetadata.a == null) {
            GeographicMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMapImageryDescriptionMetadata.c(GeographicMapImageryDescriptionMetadata.a);
        }
        if (a.k(GeographicMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.ac(GeographicMapImageryDescriptionMetadata.a);
        GeographicMapDescriptionMetadata.d(a);
        ImageTilesReadyEventArgsDescriptionMetadata.d(a);
        ImagesChangedEventArgsDescriptionMetadata.d(a);
        CancellingMultiScaleImageEventArgsDescriptionMetadata.d(a);
        DownloadingMultiScaleImageEventArgsDescriptionMetadata.d(a);
    };
    GeographicMapImageryDescriptionMetadata.c = function (a) {
        a.item("WindowRect", "Rect");
        a.item("GeographicMap", "ExportedType:XamGeographicMap");
        a.item("Referer", "String");
        a.item("IsHorizontalWrappingEnabled", "Boolean");
        a.item("UserAgent", "String");
        a.item("Opacity", "Number:double");
        a.item("ImageTilesReadyRef", "EventRef::imageTilesReady");
        a.item("ImagesChangedRef", "EventRef::imagesChanged");
        a.item("CancellingImageRef", "EventRef::cancellingImage");
        a.item("DownloadingImageRef", "EventRef::downloadingImage");
    };
    GeographicMapImageryDescriptionMetadata.d = function (a) {
        GeographicMapImageryDescriptionMetadata.b(a);
        a.ad("GeographicMapImagery", GeographicMapImageryDescriptionMetadata.a);
    };
    GeographicMapImageryDescriptionMetadata.$t = markType(GeographicMapImageryDescriptionMetadata, 'GeographicMapImageryDescriptionMetadata');
    GeographicMapImageryDescriptionMetadata.a = null;
    return GeographicMapImageryDescriptionMetadata;
}(Base));
export { GeographicMapImageryDescriptionMetadata };
